/*UWAGA w tym pliku konfiguracyjnym puste linnie oddzielaja kolejne tlumaczenia , tzn
*************
*[etykieta]
*bla bla bla
*   <-pusta linnia (tzn \n)
*costam
*
*[etykieta]
********************
* sprawi ze costam nie bedzie wpisane do [etykiety] - nie bedzie nigdzie wpisane, zamiast \n program uzywa | (<-nowa linnia)
*/
@  /*do not delete this - start interface section */
[E_OPEN]
Otworz

[E_OPEN_DESC]
Otworz plik

[E_SAVE]
Zapisz

[E_SAVE_DESC]
Zapisz plik

[E_SAVE_AS]
Zapisz jako

[E_SAVE_AS_DESC]
Zapisz plik jako

[E_FILE]
Plik

[E_MOVE_ALL]
Przesun wszystkie

[E_MOVE_ALL_DESC]
Przesun wszystkie napisy

[E_MOVE_PARTLY]
Przesun czesciowo

[E_MOVE_PARTLY_DESC]
Przesun czesciowo - od punktu do punktu

[E_CHANGE_FORMAT]
Zmien format

[E_CHANGE_FORMAT_DESC]
Zmien format pliku

[E_MERGE]
Polacz dwa pliki

[E_MERGE_DESC]
polacz dwa pliki w jeden

[E_CONVERT_ISO_1]
Konvertuj do iso-8859-1

[E_CONVERT_ISO_1_DESC]
Konvertuj z windowsowego formatu pseudo-iso 2

[E_CONVERT_ISO_2]
Konvertuj do iso-8859-2

[E_CONVERT_ISO_2_DESC]
Konvertuj z windowsowego formatu pseudo-iso 2

[E_EXIT]
Wyjdz

[E_EXIT_DESC]
Opusc program

[E_PREFERENCES]
Wlasciwosci

[E_PREFERENCES_WINDOW]
Wlasciwosci:

[E_SETTINGS]
Opcje

[E_HELP]
Pomoc

[E_ABOUT]
O programie...

[E_EDIT]
Edycja

[E_QUIT]
Wyjdz

[E_MOVE_FROM]
Przesun od:

[E_MOVE_TO]
Przesun do:

[E_DELETE]
Usun

[E_CHANGE]
Zmien

[E_INSERT]
Wstaw

[E_FAQ]
Faq

[E_BUGS_DEVEL]
Bledy i rozwijanie

[E_TIME_FRAMES]
Czas / Klatki

[E_SUBTITLE]
Napis

[E_PROPERTIES]
Opcje:

[E_TIME]
Czas:

[E_CHOOSE_FILE]
Wybierz plik:

[E_CHOOSE_FORMAT]
Wybierz format:

[E_FILE_ACCESS]
Dost. do pliku:

[E_GENERAL]
Ogolne

[E_LANG]
Jezyk

[E_LANG_DIR]
Katalog :

[E_TEMP_DIR]
Kat. tymczasowy:

[E_HOW_MANY_HOURS]
O ile godzin przesunac napisy?

[E_HOW_MANY_MIN]
O ile minut przesunac napisy?

[E_HOW_MANY_SEC]
O ile sekund przesunac napisy?

[E_WHAT_DIRECTION]
W ktorym kierunku? 

[E_HOUR_MINUTE_SECOND]
GODZ     :    MIN     :    SEK

[E_FRAME_MICRODVD]
Klatki (Microdvd)

[E_FROM]
Od:

[E_TO]
Do:

[E_FRAMES_IN_ONE_SEC]
TYLKO DLA FORMATU MICRODVD          Ile klatek wyswietlane
jest w 1 sek filmu?

[E_INFORMATION]
Informacje

[E_MOVE_FROM_POINT_TO_POINT]
Przesun od <punktu> do <punktu>

[E_TEXT_ABOUT]
GTKsubtitler to maly programik do edycji napisow dla filmow DivX (i nie tylko).
Obsluguje nastepujace formaty napisow :
*) MicroDVD
*) Czasowy
*) SubRip
*) SubViewer 2.0
Szczegoly na stronie domowej programu <www.gtksubtitler.prv.pl>|
GTKsubtitler potrafi przesowac napisy, laczyc 2 lub wiecej plikow w 1, zmieniac format napisow i konwertowac z windowsowego formatu (pseudo iso-8859-2) na iso-8859-1/2  - dokladniej jest to zamienienie kodow ascii z windowsowych na linuxowe (w Windowsie ogonki maja inne kody ascii niz w linuxie, przez co gdy mamy napisy do filmu sformatowane pod windowsa to gdy wezmiemy je do linuxa to w czasie ogladania filmu niektore polskie znaki beda pojawiac sie jako tzw \"krzaczki\" )  
|Program udostepiony jest na licencji GNU GPL

[E_TEXT_FAQ]
Skad moge sciagnac najnowsza wersje programu?
Wejdz na stronke www.gtksubtitler.prv.pl, tam znajdziesz najnowsza wersje programu.
|Znalazlem blad w programie, co mam zrobic?
Upewnij sie ze masz najnowsza wersje programu, jesli tak to wyslij mi maila na adres pawelb@gower.pl z pelnym opisem bledu.

[E_TEXT_DEVEL]
Jesli chcesz pomoc w rozwijaniu programu wyslij mi maila i napisz co mozesz zrobic, co umiesz a ja przydziele ci jakies zadanie. 
Aby rozwijac program nie musisz byc mistrzem w programowaniu w C i GTK (ja sam kiepsko programuje:)) tzn nawet nie musisz wogole programowac - mozesz przetlumaczyc interfejs programu (plik lang.pl) na jakis inny jezyk, albo poprawic istniejace tlumaczenie.


# /*do not delete this - start callbacks section */
[CANT_READ_TMP_FILE]
Nie moge czytac pliku tymczasowego!

[CANT_WRITE_TO_TMP_FILE]
Nie moge zapisac pliku tymczasowego!

[CANT_WRITE_TO_FILE]
Nie moge zapisac pliku!

[CANT_OPEN_FILE]
Nie moge otworzyc pliku!

[CANT_READ_FILE]
Nie moge czytac pliku (zly format) !

[CANT_MOVE_SUBTITLES]
Nie moge przesunac napisow tak daleko!

[FIRST_OPEN_FILE]
Najpierw otworz plik!

[FORMAT_NOT_SUPPORTED]
Ten format nie jest obslugiwany!

[INCOMPATIBILE FILE FORMAT]
Niekompatybilny format, zmien format pliku !!!

[SET_FROM_TO]
Podaj przedzial na jakim chcesz przesuwac napisy!

[MOVE_PARTLY_ON]
Przesun od ... do ...

[MOVE_PARTLY_OFF]
Jesli chcesz przesunac czesc napisow wybierz "Przesun czesciowo" z menu

[RESTART]
Zmiany zadzialaja po ponownym uruchomieniu programu
